/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	<fcntl.h>
#include	<stdlib.h>
#include	"init.h"
#include	"long_char.h"
#include	"memory_routine.h"
#include	"xl.h"
#include	"utils.h"
#include	"gb.h"
#include	"filespace.h"

void init_pdbp_function(XLISP_ENV * env0,XLISP_ENV * env1);


int
_main(int argc,char ** argv)
{


	init_xl(INI_DONTWAITCHI);
	init_cache();

	gc_push(0,0,"main");
	init_gbs();

	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
	init_pdbp_function(gblisp_top_env0,gblisp_top_env1);
	gc_pop(0,0);

	xl_setup_file(argc,argv);
	return 0;
}
